pub struct Polygon2 {
pub vertices: VecDeque<Vec2>,
}Fields
vertices: VecDeque<Vec2>Implementations
Sourceimpl Polygon2
impl Polygon2
Sourcepub fn terminal(&self, terminal: PolygonTerminal) -> Option<Vec2>
pub fn terminal(&self, terminal: PolygonTerminal) -> Option<Vec2>
Returns the terminal vertex of the polygon, or None if the polygon is empty.
Sourcepub fn extend_by_line(
&mut self,
terminal: PolygonTerminal,
other_line_end: Vec2,
)
pub fn extend_by_line( &mut self, terminal: PolygonTerminal, other_line_end: Vec2, )
Extends the polygon by a line from the terminal vertex to other_line_end.
Sourcepub fn merge_polygon(
&mut self,
my_terminal: PolygonTerminal,
other: Polygon2,
other_terminal: PolygonTerminal,
)
pub fn merge_polygon( &mut self, my_terminal: PolygonTerminal, other: Polygon2, other_terminal: PolygonTerminal, )
This assumes that the polygon to be merged doesn’t contain any vertices that are already part of this polygon.
Sourcepub fn is_closed(&self) -> bool
pub fn is_closed(&self) -> bool
Returns true if the polygon is closed (the terminal vertex is the same as the first vertex).
Sourcepub fn close(&mut self)
pub fn close(&mut self)
Closes the polygon by adding the terminal vertex to the front if it is not already closed.
Sourcepub fn length(&self) -> f32
pub fn length(&self) -> f32
Returns the length (cumulative distance between vertices) of the polygon.
Sourcepub fn min_max(&self) -> (Vec2, Vec2)
pub fn min_max(&self) -> (Vec2, Vec2)
Returns the minimum and maximum coordinates of the polygon.
The minimum is the smallest x and y values, and the maximum is the largest x and y values.
The pair forms an AABB (axis-aligned bounding box) that encloses the polygon.
Sourcepub fn contains_point(&self, point: Vec2) -> bool
pub fn contains_point(&self, point: Vec2) -> bool
Wether a point is inside the polygon.
Assumes that the polygon is closed.